==> staging-demo-20260116_092220.tar.gz: var/www/html/staging-demo/var/tmp/twig/2a/2a57bab848ed25c4dffb826c06481fac.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fp-form/js/forms.js */
class __TwigTemplate_cb21a8ecf58b7b6a06ddc93b75c6e04a extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "\"use strict\";

(() => {
    
    var forms = document.getElementsByClassName('mauticform_wrapper');
    var processedForms = [];

    const observer = new MutationObserver(() => {
        for (let form of forms) {
            if (processedForms.includes(form.id)) {
                continue;
            }

            updateForm(form);
            processedForms.push(form)
        }
    });

    observer.observe(document.body, {
        childList: true,
        subtree: true,
    });

    function updateForm(form) {    
        const breakRows = form.querySelectorAll('[class*=\"mf-col-\"].mf-break');
        breakRows.forEach(row => {
            console.log(row);
            row.classList.remove('mf-break');
            row.insertAdjacentHTML('beforebegin', '<div class=\"mf-break\"></div>');
        });
    }

})();
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fp-form/js/forms.js";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fp-form/js/forms.js", "/var/www/html/staging-demo/themes/fp-form/js/forms.js");
    }
}

==> staging-demo-20260214_100754.tar.gz: var/www/html/staging-demo/var/tmp/twig/2a/2a57bab848ed25c4dffb826c06481fac.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fp-form/js/forms.js */
class __TwigTemplate_cb21a8ecf58b7b6a06ddc93b75c6e04a extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "\"use strict\";

(() => {
    
    var forms = document.getElementsByClassName('mauticform_wrapper');
    var processedForms = [];

    const observer = new MutationObserver(() => {
        for (let form of forms) {
            if (processedForms.includes(form.id)) {
                continue;
            }

            updateForm(form);
            processedForms.push(form)
        }
    });

    observer.observe(document.body, {
        childList: true,
        subtree: true,
    });

    function updateForm(form) {    
        const breakRows = form.querySelectorAll('[class*=\"mf-col-\"].mf-break');
        breakRows.forEach(row => {
            console.log(row);
            row.classList.remove('mf-break');
            row.insertAdjacentHTML('beforebegin', '<div class=\"mf-break\"></div>');
        });
    }

})();
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fp-form/js/forms.js";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fp-form/js/forms.js", "/var/www/mautic-ktn/themes/fp-form/js/forms.js");
    }
}
